@@ -3,6 +3,7 @@
 from imio.helpers.content import add_file
 from imio.helpers.content import add_image
 from imio.helpers.content import add_to_annotation
+from imio.helpers.content import base_getattr
 from imio.helpers.content import create
 from imio.helpers.content import del_from_annotation
 from imio.helpers.content import disable_link_integrity_checks
@@ -12,6 +13,7 @@ from imio.helpers.content import get_object
 from imio.helpers.content import get_relations
 from imio.helpers.content import get_schema_fields
 from imio.helpers.content import get_state_infos
+from imio.helpers.content import get_transitions
 from imio.helpers.content import get_user_fullname
 from imio.helpers.content import get_vocab
 from imio.helpers.content import normalize_name
@@ -400,3 +402,23 @@ class TestContentModule(IntegrationTestCase):
         self.assertEqual(get_user_fullname("user1"), 'Stéphan Smith')
         self.assertEqual(user1.getProperty("fullname"), get_user_fullname("user1"))
         self.assertEqual(get_user_fullname("user2"), 'user2')
+
+    def test_get_transitions(self):
+        obj = api.content.create(container=self.portal.folder, id='mydoc', type='Document')
+        self.assertEqual(get_transitions(obj),
+                         ['publish_internally', 'hide', 'submit'])
+        transitions(obj, 'submit')
+        self.assertEqual(get_transitions(obj),
+                         ['publish_internally', 'retract', 'publish_externally', 'reject'])
+        transitions(obj, 'publish_externally')
+        self.assertEqual(get_transitions(obj), ['retract'])
+
+    def test_base_getattr(self):
+        obj = api.content.create(container=self.portal.folder, id='mydoc', type='Document')
+        self.assertTrue(self.portal.folder.getImmediatelyAddableTypes())
+        # getattr uses acquisition
+        self.assertTrue(getattr(self.portal.folder, 'getImmediatelyAddableTypes'))
+        self.assertTrue(getattr(obj, 'getImmediatelyAddableTypes'))
+        # base_getattr does not use acquisition
+        self.assertTrue(base_getattr(self.portal.folder, 'getImmediatelyAddableTypes'))
+        self.assertIsNone(base_getattr(obj, 'getImmediatelyAddableTypes'))
